@@ -77,12 +77,14 @@ def from_file():
     try:
         with open(args.filename[0]) as f:
             python_plus_code = f.read().rstrip()
-            python_code = convert(python_plus_code)
+            python_code = convert(python_plus_code).rstrip()
             if args.debug:
-                print('\033[2mPython+ Code:\033[0m\n' + python_plus_code + '\n')
+                print('\n\033[2mPython+ Code:\033[0m\n' + python_plus_code + '\n')
                 print('\033[2mPython3 Code:\033[0m\n' + python_code + '\n')
                 print('\033[2mOutput:\033[0m')
-            exec(python_code)
+            d = {}
+            for line in python_code.splitlines():
+                exec(python_code, globals=d, locals=d)
             return 0
     except Exception as e:
         print('\033[1;31mAn error occurred:', e, '\033[0m')
